import 'leaflet/dist/leaflet.css';
import 'react-loader-spinner/dist/loader/css/react-spinner-loader.css';

import { ROUTE_URL } from 'constant/other';
import CallbackPage from 'pages/CallbackPage';
import CloudProjectPage from 'pages/CloudProjectPage';
import CloudResourceStorePage from 'pages/CloudResourceStorePage';
import CloudServerTemplatePage from 'pages/CloudServerTemplatePage';
import EntityCreatePage from 'pages/EntityCreatePage';
import EntityDetailPage from 'pages/EntityDetailPage';
import EntityViewPage from 'pages/EntityViewPage';
import EntityXxudPage from 'pages/EntityXxudPage';
import LoginPage from 'pages/LoginPage';
import ProviderPage from 'pages/ProviderPage';
import { BrowserRouter, Route, Switch } from 'react-router-dom';
import { AppContext, useAppState } from 'service/state';

/**
 * Component for application route.
 */
const App = () => {

  const appState = useAppState();

  return <BrowserRouter basename={ROUTE_URL}>
    <Switch>
      <Route exact path="/">
        <LoginPage />
      </Route>
      <Route path="/callback">
        <CallbackPage />
      </Route>
      <AppContext.Provider value={appState}>
        <Route path="/providers">
          <ProviderPage />
        </Route>
        <Route path="/k8s_cost_store">
          <CloudResourceStorePage bundleId="k8s_cost_store" />
        </Route>
        <Route path="/k8s_namespace_resource_store">
          <CloudResourceStorePage bundleId="k8s_namespace_resource_store" />
        </Route>
        <Route path="/k8s_node_resource_store">
          <CloudResourceStorePage bundleId="k8s_node_resource_store" />
        </Route>
        <Route path="/k8s_pod_resource_store">
          <CloudResourceStorePage bundleId="k8s_pod_resource_store" />
        </Route>
        <Switch>
          <Route path="/:cloudServiceProvider/project">
            <CloudProjectPage />
          </Route>
          <Route path="/:cloudServiceProvider/server_template">
            <CloudServerTemplatePage />
          </Route>
          <Switch>
            <Route path="/:cloudServiceProvider/:cloudContext/project">
              <CloudProjectPage />
            </Route>
            <Route path="/:cloudServiceProvider/:cloudContext/server_template">
              <CloudServerTemplatePage />
            </Route>
            <Route path="/:cloudServiceProvider/:cloudContext/:entityName/:entityId/:action">
              <EntityXxudPage />
            </Route>
            <Route exact path="/:cloudServiceProvider/:cloudContext/:entityName/create">
              <EntityCreatePage action="create" />
            </Route>
            <Route exact path="/:cloudServiceProvider/:cloudContext/:entityName/import">
              <EntityCreatePage action="import" />
            </Route>
            <Route path="/:cloudServiceProvider/:cloudContext/:entityName/:entityId">
              <EntityDetailPage />
            </Route>
            <Route path="/:cloudServiceProvider/:cloudContext/:entityName">
              <EntityViewPage />
            </Route>
            <Route path="/:cloudServiceProvider/:entityName">
              <EntityViewPage />
            </Route>
          </Switch>
        </Switch>
      </AppContext.Provider>
    </Switch>
  </BrowserRouter>;

}

export default App;
