import EntityFormTemplate from 'model/EntityFormTemplate';

const AWS_CLOUD_INSTANCE_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'associate_elastic_ip',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Select Elastic IP',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Elastic IP', name: 'allocation_id',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/elastic_ips',
            defaultValue: ''
          },
          {
            type: 'select', labelName: 'Private IP', name: 'network_interface_id',
            url: '/cloud_dashboard/aws_cloud/aws_cloud_instance/{entity_id}/private_ips',
            defaultValue: ''
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'create_image',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Image',
        keyValueRecords: [
          { labelName: 'Image Name', name: 'image_name', type: 'default', defaultValue: '', required: true },
          { labelName: 'No Reboot', name: 'no_reboot', type: 'boolean', defaultValue: false },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{name}} {{entityName}}?',
      }
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Instance',
        keyValueRecords: [
          { labelName: 'Name', name: 'name', type: 'default', defaultValue: '', required: true },
          { labelName: 'Instance ID', name: 'instance_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Instance State', name: 'instance_state', type: 'default', defaultValue: '', readOnly: true },
          {
            type: 'select', labelName: 'Instance type', name: 'instance_type',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/instance_types',
            defaultValue: '', readOnly: true
          },
          { labelName: 'Cost', name: 'cost', type: 'cost' },
          {
            type: 'select', labelName: 'IAM role', name: 'iam_role',
            url: '/cloud_dashboard/aws_cloud/{cloud_context}/iam_role_options',
            defaultValue: ''
          },
          { labelName: 'AMI Image', name: 'image_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Kernel Image', name: 'kernel_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Ramdisk Image', name: 'ramdisk_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Virtualization', name: 'virtualization', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Reservation', name: 'reservation', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'AWS account ID', name: 'account_id', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Launch Time', name: 'launch_time', type: 'datetime', defaultValue: 0, readOnly: true },
          { labelName: 'Created', name: 'created', type: 'datetime', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          {
            labelName: 'Elastic IP', name: 'public_ip', type: 'join', info: {
              entityTypeId: 'aws_cloud_elastic_ip',
              keyColumn: 'public_ip',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Private IPs', name: 'private_ips', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Public DNS', name: 'public_dns', type: 'default', defaultValue: '', readOnly: true },
          {
            type: 'multi-select', labelName: 'Security groups', name: 'security_groups',
            url: '/cloud_dashboard/aws_cloud/aws_cloud_instance/{entity_id}/security_groups_options',
            defaultValue: []
          },
          {
            labelName: 'Key pair name', name: 'key_pair_name', type: 'join', info: {
              entityTypeId: 'aws_cloud_key_pair',
              keyColumn: 'key_pair_name',
            }, defaultValue: '', readOnly: true
          },
          {
            labelName: 'VPC ID', name: 'vpc_id', type: 'join', info: {
              entityTypeId: 'aws_cloud_vpc',
              keyColumn: 'vpc_id',
            }, defaultValue: '', readOnly: true
          },
          {
            labelName: 'Subnet ID', name: 'subnet_id', type: 'join', info: {
              entityTypeId: 'aws_cloud_subnet',
              keyColumn: 'subnet_id',
            }, defaultValue: '', readOnly: true
          },
          { labelName: 'Network interfaces', name: 'network_interfaces', type: 'array', defaultValue: [], readOnly: true },
          { labelName: 'Availability Zone', name: 'availability_zone', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Storage',
        keyValueRecords: [
          { labelName: 'Root Device Type', name: 'root_device_type', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Root Device', name: 'root_device', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'EBS Optimized', name: 'ebs_optimized', type: 'boolean', defaultValue: false, labels: ['On', 'Off'], readOnly: true },
          { labelName: 'Volume', name: 'block_devices', type: 'default', defaultValue: '', readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          {
            type: 'key-value', labelName: 'Tags', name: 'tags',
            defaultValue: []
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Option',
        keyValueRecords: [
          { labelName: 'Termination Date', name: 'termination_timestamp', type: 'datetime', defaultValue: 0 },
          { labelName: 'User data', name: 'user_data', type: 'textarea', defaultValue: '' },
          { labelName: 'User data is base64 encoded', name: 'is_user_data_binary', type: 'boolean', defaultValue: false },
          { labelName: 'Termination protection', name: 'termination_protection', type: 'boolean', defaultValue: false },
          { labelName: 'Monitoring Enabled', name: 'monitoring', type: 'boolean', defaultValue: false, labels: ['Enabled', 'Disabled'], readOnly: true },
          { labelName: 'AMI Launch Index', name: 'ami_launch_index', type: 'default', defaultValue: '', readOnly: true },
          { labelName: 'Tenancy', name: 'tenancy', type: 'default', defaultValue: '', readOnly: true },
          {
            type: 'select', labelName: 'Schedule', name: 'schedule',
            url: '/cloud_dashboard/schedule_options',
            defaultValue: ''
          },
          { labelName: 'Login Username', name: 'login_username', type: 'default', defaultValue: '', readOnly: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'reboot',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to reboot the {{name}} {{entityName}}?',
      }
    ],
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'start',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to start the {{name}} {{entityName}}?',
      }
    ],
  },
  {
    cloudServiceProvider: 'aws_cloud',
    entityName: 'instance',
    actionType: 'stop',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to stop {{name}} {{entityName}}?',
      }
    ],
  },
]

export default AWS_CLOUD_INSTANCE_TEMPLATE;
