import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_FLOATING_IP_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'floating_ip',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Floating IP',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'select', labelName: 'Floating network ID', name: 'floating_network_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/floating_network_ids',
            defaultValue: '', required: true
          },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'floating_ip',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Floating IP',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '' },
          { type: 'default', labelName: 'Type', name: 'elastic_ip_type', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Floating IP', name: 'public_ip', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Private IP Address', name: 'private_ip_address', defaultValue: '', readOnly: true },
          { type: 'datetime', labelName: 'Created', name: 'created', defaultValue: 0, readOnly: true },
        ]
      },
      {
        type: 'panel',
        panelName: 'Assign',
        keyValueRecords: [
          {
            type: 'join', labelName: 'Instance ID', name: 'instance_id', info: {
              entityTypeId: 'openstack_instance',
              keyColumn: 'name',
            }, defaultValue: '', readOnly: true
          },
          {
            type: 'join', labelName: 'Network interface ID', name: 'network_interface_id', info: {
              entityTypeId: 'openstack_network_interface',
              keyColumn: 'name',
            }, defaultValue: '', readOnly: true
          },
          { type: 'default', labelName: 'Allocation ID', name: 'allocation_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Association ID', name: 'association_id', defaultValue: '', readOnly: true },
          { type: 'default', labelName: 'Network interface owner', name: 'network_interface_owner', defaultValue: '', readOnly: true },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'floating_ip',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'floating_ip',
    actionType: 'associate',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Select the instance OR network interface',
        keyValueRecords: [
          { type: 'select-local', name: 'resource_type', labelName: 'Resource type', defaultValue: 'instance', value: [
            { name: 'instance', labelName: 'Instance' },
            { name: 'network_interface', labelName: 'Network interface' },
          ] },
          { type: 'select', labelName: 'Instance', name: 'instance_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/openstack_floating_ip/{entity_id}/unassociated_instance_ids',
            defaultValue: ''
          },
          { type: 'select', labelName: 'Private IP', name: 'instance_private_ip',
            url: '/cloud_dashboard/openstack/{cloud_context}/openstack_floating_ip/{entity_id}/instance_private_ips/{instance_id}',
            defaultValue: ''
          },
          { type: 'select', labelName: 'Network interface', name: 'network_interface_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/openstack_floating_ip/{entity_id}/unassociated_network_interface_ids',
            defaultValue: ''
          },
          { type: 'select', labelName: 'Private IP', name: 'network_interface_private_ip',
            url: '/cloud_dashboard/openstack/{cloud_context}/openstack_floating_ip/{entity_id}/network_interface_private_ips/{network_interface_id}',
            defaultValue: ''
          },
        ]
      }
    ],
    submitButtonLabel: 'Associate Address'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'floating_ip',
    actionType: 'disassociate',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to disassociate this {{entityName}}({{name}})?'
      },
      {
        type: 'panel',
        panelName: 'Floating IP Information',
        keyValueRecords: [
          {
            type: 'join', labelName: 'Instance ID', name: 'instance_id', info: {
              entityTypeId: 'openstack_instance',
              keyColumn: 'name',
            }, defaultValue: '', readOnly: true
          },
          {
            type: 'join', labelName: 'Network ID', name: 'network_interface_id', info: {
              entityTypeId: 'openstack_network_interface',
              keyColumn: 'name',
            }, defaultValue: '', readOnly: true
          }
        ]
      }
    ],
    submitButtonLabel: 'Disassociate Address'
  },
]

export default OPENSTACK_FLOATING_IP_TEMPLATE;
