/**
 * Label name and data attribute's key of entity.
 */

import KeyValueItem from 'model/KeyValueItem';
import SecurityGroupPermission from 'model/SecurityGroupPermission';

type EntityFormColumnBase = {
  labelName: string,
  name: string,
  required?: boolean,
  readOnly?: boolean,
}

type EntityFormColumnInfo = {
  type: 'default' | 'textarea' | 'hidden',
  defaultValue: string,
  defaultValueUrl?: string,
} | {
  type: 'number-array',
  defaultValue: number[],
} | {
  type: 'array',
  defaultValue: string[],
} | {
  type: 'number' | 'datetime',
  defaultValue: number,
} | {
  type: 'key-value',
  defaultValue: KeyValueItem[],
} | {
  type: 'join',
  info: {
    entityTypeId: string,
    keyColumn: string,
    label?: string,
  },
  defaultValue: string,
} | {
  type: 'select',
  url: string,
  defaultValue: string,
  defaultValueUrl?: string,
} | {
  type: 'select-local',
  value: { labelName: string, name: string }[],
  defaultValue: string,
} | {
  type: 'multi-select',
  url: string,
  defaultValue: string[],
} | {
  type: 'radio',
  value: { labelName: string, name: string }[],
  defaultValue: string,
  orientation: 'horizontal' | 'vertical'
} | {
  type: 'boolean',
  defaultValue: boolean,
  labels?: [string, string],
};


type EntityFormColumn = (EntityFormColumnBase & EntityFormColumnInfo) | {
  type: 'time',
  labelName: string,
  hourName: string,
  minuteName: string,
  defaultValue: [string, string],
  required?: boolean,
  readOnly?: boolean,
} | {
  type: 'cost',
  labelName: string,
  name: string,
} | {
  type: 'sg_permission',
  labelName: string,
  name: string,
  defaultValue: SecurityGroupPermission[],
} | {
  type: 'file',
  labelName: string,
  name: string,
};

export default EntityFormColumn;
