import DataColumn from 'model/DataColumn';
import DataRecord from 'model/DataRecord';
import DataTableData from 'molecules/DataTableData';

/**
 * Row data of DataTable.
 *
 * @param dataRecord Record of data.
 * @param dataColumn List of DataColumn.
 * @param className Parameter of className.
 * @param detailInfo Information required to create a link to more information.
*/
const DataTableRow = ({ dataRecord, dataColumnList, className, detailInfo }: {
  dataRecord: DataRecord,
  dataColumnList: DataColumn[],
  className?: string,
  detailInfo?: {
    column: string,
    path: string,
  },
}) => {

  return <tr key={dataRecord.id} className={className}>
    {dataColumnList.map((dataColumn) => {
      let link = undefined;
      if (dataColumn.key === detailInfo?.column) {
        const temp = detailInfo.path.split('/');
        link = `/${temp[1]}/${dataRecord.cloudContext}/${temp[2]}/${dataRecord.id}`;
      }

      return <DataTableData key={dataColumn.key} text={
        dataColumn.key in dataRecord.value
          ? dataRecord.value[dataColumn.key]
          : ''
      } link={link} />;
    })}
  </tr>;

}

export default DataTableRow;
