import { getMenuTemplateList } from 'constant/menu_template';
import CloudServiceProvider from 'model/CloudServiceProvider';
import React, { useEffect, useState } from 'react';
import { BsChevronDown, BsChevronUp } from 'react-icons/bs';
import { Link } from 'react-router-dom';
import { getEntityListViewUrl } from 'service/utility';

/**
 * Tab elements for entity view.
 *
 * @param menuType Cloud service provider.
 * @param menuName Active tab name.
 */
const EntityTabs = ({ menuType, entityName, cloudContext }: {
  menuType: CloudServiceProvider,
  entityName: string,
  cloudContext?: string
}) => {

  const [tabColumnList, setTabColumnList] = useState<{
    location: string;
    entityName: string;
    title: string;
  }[]>([]);
  const [foldFlg, setFoldFlg] = useState(true);

  useEffect(() => {
    setTabColumnList(
      getMenuTemplateList(menuType)
        .map((menu) => {
          return {
            location: getEntityListViewUrl(menu, cloudContext),
            entityName: menu.entityName,
            title: menu.labelName,
          };
        })
    );
  }, [menuType, entityName, cloudContext]);

  return <nav className="tabs">
    <div className={'tabs-wrap' + (foldFlg ? '' : ' wrapflex')}>
      <ul className="nav nav-tabs">
        {
          tabColumnList.map((tabColumn) => {

            return <li className={entityName === tabColumn.entityName ? 'active' : ''}>
              <Link to={tabColumn.location}
                className="active is-active ripple-effect">
                {tabColumn.title}
              </Link>
            </li>;
          })
        }
      </ul>
      { /* eslint-disable-next-line */ }
      <a href="#" className="tab-icon" onClick={(e) => {
        e.preventDefault();
        setFoldFlg(f => !f);
      }}>
        {
          foldFlg
            ? <BsChevronDown />
            : <BsChevronUp />
        }
      </a>
    </div>
  </nav>;

}

export default EntityTabs;
