import EntityInfoPanelData from 'model/EntityInfoPanelData';
import D3MetricsBlock from 'molecules/D3MetricsBlock';
import KeyValueBlock from 'molecules/KeyValueBlock';
import TableBlock from 'molecules/TableBlock';
import { Card } from 'react-bootstrap';
import { useTranslation } from 'react-i18next';

/**
 * Panel of entity detail info.
 *
 * @param index Index for panel accordion logic.
 * @param panelData Entity info.
 */
const EntityInfoPanel = ({ index, panelData }: {
  index: number, panelData: EntityInfoPanelData
}) => {

  const { t } = useTranslation();

  return <details className="card" open>
    <summary role="button" aria-expanded="true" area-pressed="true"
      className="card-header">{t(panelData.title)}</summary>
    <Card.Body className="details-wrapper">
      {
        panelData.records.map((record) => {
          return <>
            <D3MetricsBlock record={record} />
            <KeyValueBlock record={record} />
            <TableBlock record={record} />
          </>;
        })
      }
    </Card.Body>
  </details>;

}

export default EntityInfoPanel;
