import { CLOUD_SERVICE_PROVIDER_LIST, ROUTE_URL } from 'constant/other';
import CloudServiceProvider from 'model/CloudServiceProvider';
import { useEffect, useState } from 'react';
import { useTranslation } from 'react-i18next';
import { useParams } from 'react-router-dom';
import { useAppState } from 'service/state';

const DEFAULT_CLOUD_CONTEXT_NAME = 'Cloud Service Provider';
const CLOUD_SERVICE_PROVIDER_INFO: Record<CloudServiceProvider, {
  entityTypeId: string,
  label: string,
}> = {
  'aws_cloud': { entityTypeId: 'instance', label: 'AWS Cloud' },
  'k8s': { entityTypeId: 'node', label: 'K8s' },
  'openstack': { entityTypeId: 'instance', label: 'OpenStack' },
  'vmware': { entityTypeId: 'vm', label: 'VMware' },
};

const SideBar = () => {

  const params: {
    cloudServiceProvider?: string,
    cloudContext?: string,
    entityName?: string,
    entityId?: string,
    action?: string
  } = useParams();
  const { cloudContextList } = useAppState();
  const { t } = useTranslation();
  const [cloudContextName, setCloudContextName] = useState(DEFAULT_CLOUD_CONTEXT_NAME);
  const [submenuStatus, setSubmenuStatus] = useState<CloudServiceProvider | ''>('');

  useEffect(() => {
    const temp = cloudContextList.filter((c) => c.name === params.cloudContext);
    setCloudContextName(
      temp.length > 0
        ? temp[0].labelName
        : DEFAULT_CLOUD_CONTEXT_NAME
    );
  }, [params, cloudContextList]);

  const getFilteredList = (cloudServiceProvider: CloudServiceProvider) => {
    return cloudContextList.filter((c) => {
      return c.name !== 'ALL' && c.cloudServiceProvider === cloudServiceProvider;
    })
  }

  // Note: The magic number 78.9843px comes from the style set in the body tag.
  return <div className="col-lg-3 col-xl-3 col-xxl-2 left-section" style={{ top: '78.9843px' }}>
    <header className="navbar-default">
      <nav className="navbar navbar-expand-lg navbar-light d-block">
        <div className="navbar-header">
          <button className="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbar-collapse" aria-controls="navbar-collapse" aria-expanded="false" aria-label="Toggle navigation">
            <svg focusable="false" aria-hidden="true" viewBox="0 0 24 24" tabIndex={-1} fill="#fff"><path d="M3 18h18v-2H3v2zm0-5h18v-2H3v2zm0-7v2h18V6H3z"></path></svg>
          </button>
          <div className="region region-navigation">
            <a className="logo navbar-btn pull-left m-md-auto text-md-center" href={`${ROUTE_URL}/providers`} title="Home" rel="home">
              <img src="/themes/contrib/rigel/logo.svg" alt="Home" />
            </a>
            <a className="name navbar-brand d-none" href={`${ROUTE_URL}/providers`} title="Home" rel="home">sample-site</a>
          </div>
        </div>
        <div className="navbar-collapse collapse">
          <div className="region region-navigation">
            <a className="logo navbar-btn pull-left m-md-auto text-md-center" href={`${ROUTE_URL}/providers`} title="Home" rel="home">
              <img src="/themes/contrib/rigel/logo.svg" alt="Home" />
            </a>
            <a className="name navbar-brand d-none" href={`${ROUTE_URL}/providers`} title="Home" rel="home">sample-site</a>
          </div>
          <div className="region region-navigation-collapsible">
            <nav role="navigation" aria-labelledby="block-rigel-main-menu-menu" className="contextual-region open">
              <h2 className="sr-only" >Main navigation</h2>
              <ul className="nav navbar-nav" role="menu">
                <li><a href={`${ROUTE_URL}/providers`}>{t('Home')}</a></li>
                <li className="dropdown">
                  <a href={`${ROUTE_URL}/providers`} className="dropdown-toggle" data-toggle="dropdown">{cloudContextName}<span className="caret"></span></a>
                  <ul className="dropdown-menu" role="menu">
                    <li className="dropdown-submenu" onClick={() => setSubmenuStatus('')}>
                      {/* eslint-disable-next-line jsx-a11y/anchor-is-valid */}
                      <a href="#" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">All<span className="caret"></span></a>
                      <ul className="dropdown-menu" role="menu">
                        <li><a href={`${ROUTE_URL}/providers`}>Cloud Service Providers</a></li>
                        {
                          CLOUD_SERVICE_PROVIDER_LIST.map((csp) => {
                            const list = getFilteredList(csp);
                            const pair = CLOUD_SERVICE_PROVIDER_INFO[csp];
                            return list.length > 0
                              ? <li key={csp}><a href={`${ROUTE_URL}/${csp}/${pair.entityTypeId}`}>{pair.label} resources</a></li>
                              : <></>;
                          })
                        }
                      </ul>
                    </li>
                    {
                      CLOUD_SERVICE_PROVIDER_LIST.map((csp) => {
                        const list = getFilteredList(csp);
                        const pair = CLOUD_SERVICE_PROVIDER_INFO[csp];
                        return list.length > 0
                          ? <li className={'dropdown-submenu' + (submenuStatus === csp ? ' open' : '')}
                            onClick={() => setSubmenuStatus(csp)} key={csp}>
                            {/* eslint-disable-next-line jsx-a11y/anchor-is-valid */}
                            <a href="#" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">{pair.label}<span className="caret"></span></a>
                            <ul className="dropdown-menu" role="menu">
                              {
                                list.map((c) => {
                                  return <li key={c.name}><a href={`${ROUTE_URL}/${c.cloudServiceProvider}/${c.name}/${pair.entityTypeId}`}>{c.labelName}</a></li>;
                                })
                              }
                            </ul>
                          </li>
                          : <></>;
                      })
                    }
                  </ul>
                </li>
                <li className="dropdown">
                  <a href="/clouds/design" className="dropdown-toggle" data-toggle="dropdown">Design<span className="caret"></span></a>
                  <ul className="dropdown-menu" role="menu">
                    <li className="dropdown-submenu">
                      <a href="/clouds" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">All<span className="caret"></span></a>
                      <ul className="dropdown-menu" role="menu">
                        {
                          getFilteredList('aws_cloud').length > 0
                            ? <li><a href={`${ROUTE_URL}/aws_cloud/server_template`}>AWS launch templates</a></li>
                            : <></>
                        }
                        {
                          getFilteredList('k8s').length > 0
                            ? <>
                              <li><a href={`${ROUTE_URL}/k8s/server_template`}>K8s launch templates</a></li>
                              <li><a href={`${ROUTE_URL}/k8s/project`}>K8s cloud projects</a></li>
                            </>
                            : <></>
                        }
                      </ul>
                    </li>
                    <li className="dropdown-submenu">
                      <a href="/clouds" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">Launch templates<span className="caret"></span></a>
                      <ul className="dropdown-menu" role="menu">
                        {
                          cloudContextList.filter((c) => {
                            return c.name !== 'ALL';
                          }).map((c) => {
                            return <li><a href={`${ROUTE_URL}/${c.cloudServiceProvider}/${c.name}/server_template`}>{c.labelName}</a></li>
                          })
                        }
                      </ul>
                    </li>
                    <li className="dropdown-submenu">
                      <a href="/clouds" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">Projects<span className="caret"></span></a>
                      <ul className="dropdown-menu" role="menu">
                        {
                          getFilteredList('k8s').map((c) => {
                            return <li key={c.name}><a href={`${ROUTE_URL}/${c.cloudServiceProvider}/${c.name}/project`}>{c.labelName}</a></li>;
                          })
                        }
                      </ul>
                    </li>
                    <li className="dropdown-submenu">
                      <a href="/clouds" className="dropdown-submenu-toggle dropdown-toggle" data-toggle="dropdown">Stores<span className="caret"></span></a>
                      <ul className="dropdown-menu" role="menu">
                        <li><a href={`${ROUTE_URL}/k8s_cost_store`}>K8s cost store</a></li>
                        <li><a href={`${ROUTE_URL}/k8s_namespace_resource_store`}>K8s namespace resource store</a></li>
                        <li><a href={`${ROUTE_URL}/k8s_node_resource_store`}>K8s node resource store</a></li>
                        <li><a href={`${ROUTE_URL}/k8s_pod_resource_store`}>K8s pod resource store</a></li>
                      </ul>
                    </li>
                  </ul>
                </li>
                <li><a href="/admin/structure/cloud_config">Config</a></li>
              </ul>
            </nav>
          </div>
        </div>
      </nav>
    </header>
  </div>;
}

export default SideBar;
