import PageSelector from 'molecules/PageSelector';
import ResourceCountLabel from 'molecules/ResourceCountLabel';
import ResourceStoreTable from 'organisms/ResourceStoreTable';
import SideBar from 'organisms/SideBar';
import { useState } from 'react';
import { Col, Container, Form, Row } from 'react-bootstrap';

/**
 * The Page of Cloud Resource Store.
 *
 * @param bundleId The bundle ID, such as k8s_cost_store.
 */
const CloudResourceStorePage = ({ bundleId }: {
  bundleId: string
}) => {
  const [itemCount, setItemCount] = useState(0);
  const [pageIndex, setPageIndex] = useState(0);

  return <>
    <SideBar />
    <Container fluid className="px-0">
      <Row className="mx-0">
        <Col>
          <Form>
            <Form.Group style={{ marginTop: '2rem' }}>
              <ResourceCountLabel
                bundleId={bundleId}
                itemCount={itemCount}
                setItemCount={setItemCount} />
            </Form.Group>
          </Form>
        </Col>
      </Row>
    </Container>
    <PageSelector
      pageIndex={pageIndex}
      setPageIndex={setPageIndex}
      itemCount={itemCount} />
    <Container fluid className="px-0">
      <Row className="mx-0">
        <Col>
          <Form>
            <ResourceStoreTable bundleId={bundleId} pageIndex={pageIndex} />
          </Form>
        </Col>
      </Row>
    </Container>
    <PageSelector
      pageIndex={pageIndex}
      setPageIndex={setPageIndex}
      itemCount={itemCount} />
  </>;
}

export default CloudResourceStorePage;
