(function ($) {
  'use strict';

  // Metrics Url.
  if (!drupalSettings.aws_cloud_monitor_metrics_url) {
    return;
  }

  // Init Chart.
  const initCharts = function () {
    d3.json(drupalSettings.aws_cloud_monitor_metrics_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function (name) {
        let selector = 'edit-' + name.replaceAll('_' , '-') + '-horizon-chart';
        let title = $('#' + selector).attr('chart-name');
        let chart_data = [];
        this.timestamps.forEach((element, index) => {
          chart_data.push([
            d3.timeParse('%Y-%m-%dT%H:%M:%S+00:00')(element),
            this.values[index],
          ]);
        });
        chart_datas.push({
          id: title,
          values: chart_data,
          selector: '#' + selector,
        });
      });
      Drupal.Cloud.drawChart(chart_datas, true);
    });
  };

  // Init Charts.
  initCharts();

  // Refresh charts.
  const interval = drupalSettings.aws_cloud_monitor_refresh_interval || 10;
  setInterval(function () {
    initCharts();
  }, interval * 1000);

  $(document).ajaxSuccess(function (event, xhr, settings) {
    if (!settings.extraData
      || settings.extraData._triggering_element_name !== 'chart_type') {
      return;
    }

    if (!$('input:radio[name="chart_type"]') || $('input:radio[name="chart_type"]:checked').val() !== '1') {
      return;
    }

    setTimeout(function () {
      initCharts();
    }, 1);
  });

})(jQuery);
