@ci_job
Feature: Allocate and release an Elastic IP as "Authenticated User"

  @javascript @api
  Scenario: Add an internet gateway
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway/add"
    And I should see the heading "Add AWS Cloud internet gateway"
    And I enter "{{ internet_gateway }}" for "Name"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the link "{{ internet_gateway }}"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages

  @javascript @api
  Scenario: Attach an internet gateway
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the heading "AWS Cloud internet gateways"
    And I click "Refresh"
    And I should see the link "{{ internet_gateway }}"
    And I should see the button "Attach"
    And I wait {{ wait }} milliseconds
    And I click "{{ internet_gateway }}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway/"
    And I click "Attach"
    And the url should match "/attach"
    And I select "{{ vpc_name }}" from "VPC CIDR (ID)"
    And I press "Attach"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the success message "is attached to VPC"
    And I should see neither error nor warning messages
    And I should see "Detach" in the "{{ internet_gateway }}" row

  @javascript  @api
  Scenario: Allocate an Elastic IP
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip/add"
    And I should see the heading "Add AWS Cloud Elastic IP"
    And I enter "{{ elastic_ip }}" for "Name"
    And I select "{{ elastic_ip_domain }}" from "Domain (Standard | VPC)"
    And I select "{{ region_code }}" from "Network border group"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages

  @javascript @api
  Scenario: Associate the Elastic IP
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context}}/elastic_ip"
    And I click "Refresh"
    And I should see the link "{{ elastic_ip }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ elastic_ip }}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context}}/elastic_ip/"
    And I click "Associate Elastic IP" in the "actions"
    And the url should match "/associate"
    And I select "{{ resource_type }}" from "Resource type"
    And I select "{{ instance_name }}" from "Instance"
    And I wait {{ wait }} milliseconds
    And I press "Associate"
    And I wait for AJAX to finish
    Then I should see the success message "associated with"
    And I should see neither error nor warning messages
    And I should see "Disassociate Elastic IP" in the "actions"

  @javascript @api
  Scenario: Disassociate the Elastic IP
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip"
    And I click "Refresh"
    And I should see the link "{{ elastic_ip }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ elastic_ip}}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip/"
    And I click "Disassociate Elastic IP" in the "actions"
    And the url should match "/disassociate"
    And I press "Disassociate Address"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip"
    And I should see the success message "Elastic IP disassociated from"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Release the Elastic IP
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip"
    And I click "Refresh"
    And I should see the link "{{ elastic_ip }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ elastic_ip }}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip/"
    And I click "Delete" in the "actions"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/{{ cloud_context }}/elastic_ip"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    # No table exists.
    And I should not see the link "{{ elastic_ip }}"

  @api @javascript
  Scenario: Detach an internet gateway
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the link "{{ internet_gateway }}"
    And I should see the button "Detach"
    And I wait {{ wait }} milliseconds
    And I click "{{ internet_gateway }}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway/"
    And I click "Detach"
    And the url should match "/detach"
    And I should see "Internet gateway information"
    And I press "Detach"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the success message "detached from VPC"
    And I should see neither error nor warning messages
    And I should see the button "Attach"

  @api @javascript
  Scenario: Delete an internet gateway
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the heading "AWS Cloud internet gateways"
    And I click "Refresh"
    And I should see the link "{{ internet_gateway }}"
    And I should see the button "Attach"
    And I wait {{ wait }} milliseconds
    And I click "{{ internet_gateway }}"
    And the url should match "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway/"
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then the url should match "/clouds/aws_cloud/{{ cloud_context }}/internet_gateway"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
