Feature: Launch EC2 instance
  In order to launch EC2 instance
  As a user
  I need to create necessary resource

  @api
  Scenario Outline: Log into the site
    Given I am logged in as a user with the <role> role
    When I visit "/clouds"
    And I should see the heading "Cloud service providers"
    And I should see the link "All" in the "nav_bar"
    And I should see the link "AWS" in the "nav_bar"

    Examples:
      | role       |
      | "BDD Role" |

  @api
  Scenario Outline: Create SSH Key Pair
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/key_pair/add"
    And I should see the heading "Add AWS Cloud key pair"
    And I enter <ssh_key_name> for "Key pair name"
    And I press "Save"
    Then the url should match "/clouds/aws_cloud/aws_bdd_us_west_1/key_pair"
    And I should see "has been created"
    And I should see the link <ssh_key_name>

    Examples:
      | role       | ssh_key_name |
      | "BDD Role" | "BDD Key"    |

  @javascript @api
  Scenario Outline: Import AMI Image
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/images/import"
    And I enter <image_id> for "Image IDs"
    And I press "Import"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/aws_bdd_us_west_1/image"
    And I should see "Imported 1 images"
    And I should see the link <image_name>

    Examples:
      | role       | image_id                | image_name                                                                |
      | "BDD Role" | "ami-0ffd5d172624ebfe2" | "ubuntu-minimal/images/hvm-ssd/ubuntu-focal-20.04-amd64-minimal-20211001" |

  @api
  Scenario Outline: Add AWS Cloud VPC
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/vpc/add"
    And I enter <vpc_name> for "Name"
    And I enter <ipv4_cidr> for "IPv4 CIDR block"
    And I press "Save"
    Then I should be on "/clouds/aws_cloud/aws_bdd_us_west_1/vpc"
    And I should see "has been created"
    And I should see the link <vpc_name>

    Examples:
      | role       | vpc_name     | ipv4_cidr     |
      | "BDD Role" | "BDD VPC"    | "10.0.0.0/24" |

  @javascript @api
  Scenario Outline: Add Cloud Subnet
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/subnet/add"
    And I enter <subnet_name> for "Name"
    And I select <vpc_name> from "VPC CIDR (ID)"
    And I select <avail_zone> from "Availability Zone"
    And I enter <ipv4_cidr> for "IPv4 CIDR block"
    And I press "Save"
    And I wait for AJAX to finish
    Then I should be on "/clouds/aws_cloud/aws_bdd_us_west_1/subnet"
    And I should see "has been created"
    And I should see the link <subnet_name>

    Examples:
      | role       | subnet_name  | vpc_name  | avail_zone   | ipv4_cidr     |
      | "BDD Role" | "BDD Subnet" | "BDD VPC" | "us-west-1a" | "10.0.0.0/24" |

  @javascript @api
  Scenario Outline: Add Cloud Security Group
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/security_group/add"
    And I enter <security_group_name> for "Security group name"
    And I enter <description> for "Description"
    And I select <vpc_name> from "VPC CIDR (ID)"
    And I press "Save"
    Then the url should match "/clouds/aws_cloud/aws_bdd_us_west_1/security_group/"
    And I should see "has been created"
    And I click "Inbound and Outbound Rules"
    And the url should match "/edit"
    And I select <ip_protocol> from "IP Protocol"
    And I enter <cidr_ip> for "CIDR IP"
    And I press "Save"
    And I wait for AJAX to finish
    And the url should match "/clouds/aws_cloud/aws_bdd_us_west_1/security_group/"
    And I should see "has been updated"
    And I should see the link <security_group_name>

    Examples:
      | role       | security_group_name  | description | vpc_name  | ip_protocol   | cidr_ip       |
      | "BDD Role" | "BDD Security Group" | "2021"      | "BDD VPC" | "All traffic" | "10.0.0.0/24" |

  @javascript @api
  Scenario Outline: Create Launch Templates
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/design/server_template/aws_bdd_us_west_1/aws_cloud/add"
    And I should see the heading "Add AWS Cloud"
    And I enter <instance_name> for "Name"
    And I select <instance_type> from "Instance Type"
    And I select <image_name> from "Image ID"
    And I select <avail_zone> from "Availability Zone"
    And I select <vpc_name> from "VPC"
    And I wait for AJAX to finish
    And I select <subnet_name> from "Subnet"
    And I select <security_group_name> from "Security Groups"
    And I select <ssh_key_name> from "SSH Key"
    And I select <status> from "Status"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/aws_bdd_us_west_1/"
    And I should see "has been created"
    And I should see the heading <instance_name>
    And I visit "/clouds/design/server_template/aws_bdd_us_west_1"
    And I should see the link <instance_name>

    Examples:
      | role       | instance_name  | instance_type | image_name                                                                | avail_zone   | vpc_name  | subnet_name  | security_group_name  | ssh_key_name | status   |
      | "BDD Role" | "BDD_Instance" | "t3.nano"     | "ubuntu-minimal/images/hvm-ssd/ubuntu-focal-20.04-amd64-minimal-20211001" | "us-west-1a" | "BDD VPC" | "BDD Subnet" | "BDD Security Group" | "BDD Key"    | "Review" |

  @javascript @api
  Scenario Outline: Launch an instance
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/design/server_template/aws_bdd_us_west_1"
    And I click <instance_name>
    And I should see the heading <instance_name>
    And I click "Approve"
    And the url should match "/approve"
    And I press "Approve"
    And the url should match "/clouds/design/server_template/aws_bdd_us_west_1/"
    And I should see "has been approved"
    When I click "Launch"
    And the url should match "/launch"
    And I check the box "Automatically terminate instance"
    And I press "Launch"
    Then I should be on "/clouds/aws_cloud/aws_bdd_us_west_1/instance"
    And I should see "pending"

    Examples:
      | role       | instance_name  |
      | "BDD Role" | "BDD_Instance" |

  @api
  Scenario Outline: View the instance
    Given I am logged in as a user with the <role> role
    When I visit "/clouds/aws_cloud/aws_bdd_us_west_1/instance"
    And I click <instance_name>
    Then the url should match "/clouds/aws_cloud/aws_bdd_us_west_1/instance/"
    And I should see the link "Info"
    And I should see the link "Monitor"
    And I should see the link "Console Output"

    Examples:
      | role       | instance_name  |
      | "BDD Role" | "BDD_Instance" |
