(function ($) {
  'use strict';

  if (!drupalSettings.k8s || !drupalSettings.k8s.k8s_namespace_costs_chart_json_url) {
    return;
  }

  let cost_type = null;
  let chart_period = null;
  if (drupalSettings.k8s.k8s_namespace_costs_chart_ec2_cost_type) {
    cost_type = drupalSettings.k8s.k8s_namespace_costs_chart_ec2_cost_type;
  }
  chart_period = drupalSettings.k8s.k8s_namespace_costs_chart_period
    ? drupalSettings.k8s.k8s_namespace_costs_chart_period
    : 1;

  $('#k8s_namespace_costs_chart').append('<div id="chart_options">');
  $('#chart_options').css('font-size', 'x-small');
  $('#chart_options').css('text-align', 'right');
  $('#chart_options').append('<span>');
  $('#chart_options').append('<span>');
  if (drupalSettings.k8s.k8s_namespace_costs_cost_types_json_url) {
    let cost_types_json_url = drupalSettings.k8s.k8s_namespace_costs_cost_types_json_url;
    $.get(cost_types_json_url, function (json) {
      $('#chart_options > span:first-child').append('<label for="cost_type">' + Drupal.t('Cost type') + '</label>');
      $('#chart_options > span:first-child').append('<select id="cost_type">');
      $.each(json, function (index, value) {
        $('#cost_type').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#cost_type option').css('font-size', 'x-small');
      if (cost_type) {
        $('#cost_type').val(cost_type);
      }
      $('#cost_type').change(function () {
        updateChart();
      });
    });
  }
  if (drupalSettings.k8s.k8s_namespace_costs_chart_periods_json_url) {
    let chart_periods_json_url = drupalSettings.k8s.k8s_namespace_costs_chart_periods_json_url;
    $.get(chart_periods_json_url, function (json) {
      $('#chart_options > span:last-child').append('<label for="chart_period">' + Drupal.t('Chart period') + '</label>');
      $('#chart_options > span:last-child label').css('margin-left', '10px');
      $('#chart_options > span:last-child').append('<select id="chart_period">');
      $.each(json, function (index, value) {
        $('#chart_period').append('<option value="' + index + '">' + value + '</option>');
      });
      $('#chart_period option').css('font-size', 'x-small');

      if (chart_period && $('select#chart_period option[value="' + chart_period + '"]').length > 0) {
        $('#chart_period').val(chart_period);
      }
      else if ($('select#chart_period option[value="1"]').length > 0) {
        $('#chart_period').val(1);
      }
      $('#chart_period').change(function () {
       updateChart();
      });
    });
  }

  const json_url = drupalSettings.k8s.k8s_namespace_costs_chart_json_url;

  const initChart = function () {
    // Using chart data sent in Page build instead of JSON request upon
    // page load.
    const chartData = drupalSettings.k8s.k8s_namespace_costs_chart_initial_data;
    let chart_datas = [];

    $.each(chartData, function (idx) {
      let namespace = this.namespace;
      let selector = namespace.replace(':' , '--');
      let cost_data = [];
      $.each(this.costs, function () {
        cost_data.push([
          new Date(this.timestamp * 1000),
          this.cost
        ]);
      });
      chart_datas.push({
        id: namespace,
        values: cost_data,
        selector: '#' + selector,
      });

      $('#k8s_namespace_costs_chart').append('<div id="' + selector + '"></div>');
    });

    Drupal.Cloud.drawChart(chart_datas, true);
  };

  let updateChart = function () {
    let update_json_url = json_url + '?' + 'cost_type=' + $('#cost_type').val() + '&period=' + $('#chart_period').val();
    d3.json(update_json_url).then(function (json) {
      let chart_datas = [];
      $.each(json, function () {
        let namespace = this.namespace;
        let selector = namespace.replace(':' , '--');
        let cost_data = [];
        $.each(this.costs, function () {
          cost_data.push([
            new Date(this.timestamp * 1000),
            this.cost
          ]);
        });
        chart_datas.push({
          id: namespace,
          values: cost_data,
          selector: '#' + selector,
        });
      });
      Drupal.Cloud.drawChart(chart_datas, true);
    });
  };

  initChart();

  let interval = drupalSettings.k8s.k8s_js_refresh_interval || 10;
  setInterval(function () {
    updateChart();
  }, interval * 1000);

})(jQuery);
