@minimal @ci_job
Feature: Create, read, update and delete cluster role binding for K8s as "Authenticated User"

  @api @javascript
  Scenario: Create a cluster role binding
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/cluster_role_binding/add"
    And I should see the heading "Add Cluster role binding"
    And I fill in "Detail" with:
    """
    apiVersion: rbac.authorization.k8s.io/v1
    kind: ClusterRoleBinding
    metadata:
      name: {{ cluster_role_binding_name }}
    subjects:
    - kind: {{ role_binding_sub_kind }}
      name: {{ role_binding_sub_user }}
      apiGroup: {{ role_binding_api }}
    roleRef:
      kind: {{ cluster_role_binding_role_kind }}
      name: {{ cluster_role_name }}
      apiGroup: {{ role_binding_api }}
    """
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see "{{ cluster_role_binding_name }}"

  @api @javascript
  Scenario: Read the cluster role binding
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I click "Refresh"
    And I should see the link "{{ cluster_role_binding_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ cluster_role_binding_name }}"
    And the url should match "/cluster_role_binding/"
    And I should see "{{ cluster_role_binding_name }}" in the "page_header"
    And I should see "{{ cluster_role_binding_name }}" in the "details"
    And I should see "{{ role_binding_sub_user }}" in the "details"
    And I should see neither error nor warning messages
    And I press "Others"
    And I should see "{{ user_name }}" in the "Authored by"

  @api @javascript
  Scenario: Update the cluster role binding
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I click "Refresh"
    And I should see the link "{{ cluster_role_binding_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ cluster_role_binding_name }}"
    And the url should match "/cluster_role_binding/"
    And I click "Edit"
    And I fill in "Detail" with:
    """
    apiVersion: rbac.authorization.k8s.io/v1
    kind: ClusterRoleBinding
    metadata:
      name: {{ cluster_role_binding_name }}
    subjects:
    - kind: {{ role_binding_sub_kind }}
      name: {{ role_binding_sub_user_edit }}
      apiGroup: {{ role_binding_api }}
    roleRef:
      kind: {{ cluster_role_binding_role_kind }}
      name: {{ cluster_role_name }}
      apiGroup: {{ role_binding_api }}
    """
    And I press "Save"
    And I wait for AJAX to finish
    And the url should match "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I click "{{ cluster_role_binding_name }}"
    And the url should match "/cluster_role_binding/"
    And I should see "{{ role_binding_sub_user_edit }}"

  @api @javascript
  Scenario: Delete the cluster role binding
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I click "Refresh"
    And I should see the link "{{ cluster_role_binding_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ cluster_role_binding_name }}"
    And the url should match "/cluster_role_binding/"
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    And I should be on "/clouds/k8s/{{ cloud_context }}/cluster_role_binding"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ cluster_role_binding_name }}"
