<?php

namespace Drupal\openstack\Entity;

use Drupal\aws_cloud\Entity\Ec2\NetworkInterface;
use Drupal\aws_cloud\Entity\Ec2\NetworkInterfaceInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the OpenStack NetworkInterface entity.
 *
 * @ingroup openstack
 *
 * @ContentEntityType(
 *   id = "openstack_network_interface",
 *   id_plural = "openstack_network_interfaces",
 *   label = @Translation("Network interface"),
 *   label_collection = @Translation("Network interfaces"),
 *   label_singular = @Translation("Network interface"),
 *   label_plural = @Translation("Network interfaces"),
 *   handlers = {
 *     "view_builder" = "Drupal\openstack\Entity\OpenStackNetworkInterfaceViewBuilder",
 *     "list_builder" = "Drupal\cloud\Controller\CloudContentListBuilder",
 *     "views_data"   = "Drupal\openstack\Entity\OpenStackNetworkInterfaceViewsData",
 *
 *     "form" = {
 *       "default" = "Drupal\openstack\Form\OpenStackNetworkInterfaceEditForm",
 *       "add" = "Drupal\openstack\Form\OpenStackNetworkInterfaceCreateForm",
 *       "edit" = "Drupal\openstack\Form\OpenStackNetworkInterfaceEditForm",
 *       "delete" = "Drupal\openstack\Form\OpenStackNetworkInterfaceDeleteForm",
 *       "delete-multiple-confirm" = "Drupal\openstack\Form\OpenStackNetworkInterfaceDeleteMultipleForm",
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *     "access" = "Drupal\aws_cloud\Controller\Ec2\NetworkInterfaceAccessControlHandler",
 *   },
 *   base_table = "openstack_network_interface",
 *   admin_permission = "administer openstack network interface",
 *   fieldable = TRUE,
 *   entity_keys = {
 *     "id"    = "id",
 *     "label" = "name",
 *     "uuid"  = "uuid",
 *   },
 *   links = {
 *     "canonical" = "/clouds/openstack/{cloud_context}/network_interface/{openstack_network_interface}",
 *     "edit-form" = "/clouds/openstack/{cloud_context}/network_interface/{openstack_network_interface}/edit",
 *     "delete-form" = "/clouds/openstack/{cloud_context}/network_interface/{openstack_network_interface}/delete",
 *     "collection" = "/clouds/openstack/{cloud_context}/network_interface",
 *     "delete-multiple-form" = "/clouds/openstack/{cloud_context}/network_interface/delete_multiple",
 *   },
 *   field_ui_base_route = "openstack_network_interface.settings"
 * )
 */
class OpenStackNetworkInterface extends NetworkInterface implements NetworkInterfaceInterface {

  /**
   * {@inheritdoc}
   */
  public function getExternal(): bool {
    return $this->get('external')->value;
  }

  /**
   * {@inheritdoc}
   */
  public function setExternal(bool $external): NetworkInterfaceInterface {
    return $this->set('external', $external);
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    // Update the label to reflect OpenStack.
    $fields['account_id']->setLabel('OpenStack account ID');

    $fields['external'] = BaseFieldDefinition::create('boolean')
      ->setLabel(t('External or Not'))
      ->setDescription(t('The network interface is external or not.'))
      ->setDisplayOptions('view', [
        'label' => 'inline',
        'type' => 'string',
        'weight' => -5,
      ])
      ->setReadOnly(TRUE);

    return $fields;
  }

}
