@minimal @ci_job
Feature: Create, read, update and delete a Snapshot for OpenStack as "Authenticated User"

  @api @javascript
  Scenario: Create a volume for a snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    # Add a volume
    When I visit "/clouds/openstack/{{ cloud_context }}/volume/add"
    And I should see the heading "Add Openstack Volume"
    And I enter "{{ volume_name }}" for "Name"
    And I enter "{{ volume_size }}" for "Size (GiB)"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/volume"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the text "creating" or "available" in the "{{ volume_name }}" row

  @api @javascript
  Scenario: Create a snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    # Confirm the volume is available.
    When I visit "/clouds/openstack/{{ cloud_context }}/volume"
    And I wait {{ wait }} milliseconds
    And I click "Refresh"
    And I should see "available" in the "{{ volume_name }}" row
    # Add a snapshot
    And I visit "/clouds/openstack/{{ cloud_context }}/snapshot/add"
    And I should see the heading "Add OpenStack Snapshot"
    And I enter "{{ snapshot_name }}" for "Name"
    And I enter "{{ description }}" for "Description"
    And I select "{{ volume_name }}" from "Volume ID"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see "{{ snapshot_name }}"

  @api @javascript
  Scenario: Read the created snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I should see "{{ snapshot_name }}"
    And I should see "{{ description }}"
    And I should see "{{ volume_size }}"
    And I press "Others"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Update the snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I click "Edit"
    And the url should match "/edit"
    And I enter "{{ snapshot_name_edit }}" for "Name"
    And I enter "{{ description_edit }}" for "Description"
    And I press "Save"
    Then I should see "{{ snapshot_name_edit }}"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I should see the link "{{ snapshot_name_edit }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_edit }}"
    And I should see "{{ snapshot_name_edit }}"
    And I should see "{{ description_edit }}"
    And I press "Others"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @api @javascript
  Scenario: Delete the snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name_edit }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_edit }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ snapshot_name_edit }}"

  @api @javascript
  Scenario: Delete the volume
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/volume"
    And I click "Refresh"
    And I should see the link "{{ volume_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ volume_name }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/volume/"
    And I click "Delete"
    And the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/volume"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ volume_name }}"
