@minimal @ci_job
Feature: Launch, stop, and terminate an instance for OpenStack as "Authenticated User"

  @api @javascript
  Scenario: Create an Launch template
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}/openstack/add"
    And I should see the heading "Add OpenStack"
    And I enter "{{ instance_name_operate }}" for "Name"
    And I select "{{ instance_flavor }}" from "Flavor"
    And I select "{{ image_name }}" from "Image ID"
    And I select "{{ availability_zone }}" from "Availability zone"
    And I select "{{ security_group_name }}" from "Security groups"
    And I select "{{ key_name }}" from "SSH key"
    # Make sure we have this network interface at OpenStack Horizon dashboard
    And I select "{{ network_name }}" from "Network interface"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the heading "{{ instance_name_operate }}"

  @api @javascript
  Scenario: Launch an instance
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "{{ instance_name_operate }}"
    And I should see the heading "{{ instance_name_operate }}"
    And I click "Launch"
    And the url should match "/launch"
    And I press "Launch"
    And I wait for AJAX to finish
    Then the url should match "/clouds/openstack/{{ cloud_context }}/instance"
    And I should see the success message "has been launched"
    And I should see neither error nor warning messages
    And I wait {{ wait }} milliseconds
    And I click "Refresh"
    And I should see "{{ instance_flavor }}" in the "{{ instance_name_operate }}" row
    And I should see "{{ availability_zone }}" in the "{{ instance_name_operate }}" row

  @api @javascript
  Scenario: View the created instance and its author
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/instance"
    And I should see the link "{{ instance_name_operate }}"
    And I click "{{ instance_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/instance/"
    And I should see "{{ instance_name_operate }}" in the "page_header"
    And I should see "{{ instance_flavor }}" in the "Instance type"
    And I should not see "{{ instance_flavor_as_first_option }}"
    And I should see "{{ image_name }}" in the "Image"
    And I should see "{{ availability_zone }}" in the "Availability Zone"
    And I should see "{{ security_group_name }}" in the "Security groups"
    And I should see "{{ key_name }}" in the "Key pair name"
    And I press "Others"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @api
  Scenario: Stop the running instance
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/instance"
    And I click "Refresh"
    And I should see "running" in the "{{ instance_name_operate }}" row
    And I wait {{ wait }} milliseconds
    And I check the box in the "{{ instance_name_operate }}" row
    And I select "Stop Instance(s)" from "Action"
    And I press "Apply to selected items"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/instance/stop_multiple"
    And I should see "{{ instance_name_operate }}"
    And I press "Stop"
    And I should be on "/clouds/openstack/{{ cloud_context }}/instance"
    And I should see the success message "has been stopped"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should see "stopped" in the "{{ instance_name_operate }}" row

  @api
  Scenario: Terminate the stopped instance
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/instance"
    And I click "Refresh"
    And I should see "stopped" in the "{{ instance_name_operate }}" row
    And I should see the link "{{ instance_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ instance_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/instance/"
    And I wait {{ wait }} milliseconds
    And I click "Delete"
    Then the url should match "/terminate"
    And I press "Delete | Terminate"
    And I should be on "/clouds/openstack/{{ cloud_context }}/instance"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should see with "stopped" in the "{{ instance_name_operate }}" row, no rows, or no table

  @api @javascript
  Scenario: Delete a launch template
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "Refresh"
    And I should see the link "{{ instance_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ instance_name_operate }}"
    And the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I click "Delete"
    Then the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    And I should be on "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should not see the link "{{ instance_name_operate }}"
